Membrane.Element.UDP.Sink (Membrane Element: UDP v0.4.0) View Source
Element that sends buffers received on the input pad over a UDP socket.
Element options
Passed via struct Membrane.Element.UDP.Sink.t/0
destination_addressRequired An IP Address that the packets will be sent to.
destination_port_noRequired A UDP port number of a target.
local_addressDefault value:
:anyAn IP Address set for a UDP socket used to sent packets. It allows to specify which network interface to use if there's more than one.local_port_noDefault value:
0A UDP port number for the socket used to sent packets. If set to0(default) the underlying OS will assign a free UDP port.
Pads
:input
| Availability | :always |
| Bin? | false |
| Caps | :any |
| Demand unit | :buffers |
| Direction | :input |
| Mode | :pull |
| Name | :input |
Link to this section Summary
Types
Struct containing options for Membrane.Element.UDP.Sink
Functions
Returns pads descriptions for Membrane.Element.UDP.Sink
Returns description of options available for this module
Link to this section Types
Specs
t() :: %Membrane.Element.UDP.Sink{
destination_address: :inet.ip_address(),
destination_port_no: :inet.port_number(),
local_address: :inet.socket_address(),
local_port_no: :inet.port_number()
}
Struct containing options for Membrane.Element.UDP.Sink
Link to this section Functions
Specs
membrane_pads() :: [{Membrane.Pad.name_t(), Membrane.Pad.description_t()}]
Returns pads descriptions for Membrane.Element.UDP.Sink
Specs
options() :: keyword()
Returns description of options available for this module